ChatService class

Service to manage the chat messages for different atsigns

Constructors

ChatService()
factory

Properties

atClientManager ↔ AtClientManager
Instance of AtClientManager
getter/setter pair
chatHistory ↔ List<Message>
getter/setter pair
chatHistoryMessages ↔ List
getter/setter pair
chatHistoryMessagesOther ↔ List
getter/setter pair
chatImageKey → String
final
chatKey → String
final
chatSink → Sink
no setter
chatStream → Stream<List<Message>>
no setter
chatStreamController ↔ StreamController<List<Message>>
getter/setter pair
chatWithAtSign ↔ String?
Atsign chatting with current atsign
getter/setter pair
currentAtSign ↔ String?
current atsign
getter/setter pair
groupChatId ↔ String?
getter/setter pair
groupChatMembers ↔ List<String>?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isGroupChat ↔ bool
getter/setter pair
monitorStarted ↔ bool
getter/setter pair
rootDomain ↔ String?
Root domain to use
getter/setter pair
rootPort ↔ int?
Root port to use
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
storageKey → String
Part of keys to identify the different AtKeys
final

Methods

constructKey(String savedKey) → AtKey
deleteMessages() → Future<bool>
deletes self owned messages only
deleteSelectedMessage(String? id) → Future<bool>
disposeControllers() → void
fieldSeparator(String data) → Map<String, String>
getChatHistory({String? atsign}) → Future<void>
getImage(String savedKey) → Future<Uint8List>
getPrivateKey(String atsign) → Future<String>
Fetches privatekey for atsign from device keychain.
initChatService(AtClientManager atClientManagerFromApp, String currentAtSignFromApp, String rootDomainFromApp, int rootPortFromApp) → void
function to set parameters passed from the calling app
interleave<T>(List a, List b) → Future<List<Message>>
function to mix the incoming and outgoing messages by timestamp
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendImageFile(BuildContext context, File file) → Future<void>
sendMessage(String? message) → Future<void>
setAtsignToChatWith(String? chatWithAtSignFromApp, bool isGroup, String? groupId, List<String>? groupMembers) → void
setChatHistory(Message message, {Uint8List? imageData}) → Future<void>
startMonitor() → Future<bool>
startMonitor needs to be called at the beginning of session called again if outbound connection is dropped
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited